#!/usr/bin/ruby
#
# example.rb

require './lib/ruby_build_ios.rb'

# This code along with the build_project_workspace fills our current need for
# setting the build's version number. We have a TODO to allow for greater flexibility
# in setting build variables
def get_build_number_string()
  build_number = RubyBuildIos.latest_git_commit_count()
  build_number = build_number += 300000000
  return build_number.to_s
end

def release_to_qa()
  archive_path = './build/qa'
  archive_file = archive_path + '/Example.xcarchive'
  
  RubyBuildIos.clean(archive_path)
  
  # Copies the provision file to the appropriately named file in ~/Library/MobileDevice/Provisioning Profiles
  # where Xcode expects to find them.
  RubyBuildIos.install_provision_file('./certs/EXAMPLE_QA_App.mobileprovision')
  RubyBuildIos.install_provision_file('./certs/EXAMPLE_QA_WKApp.mobileprovision')
  RubyBuildIos.install_provision_file('./certs/EXAMPLE_QA_WKExt.mobileprovision')
  
  # build_workspace(workspace, scheme, configuration, build_number, archive_path)
  RubyBuildIos.build_workspace('Example.xcworkspace', 'Example', 'QA', get_build_number_string(), archive_file)

  #upload the app to hockey
  api_token = '<YOUR HOCKEY API TOKEN>'
  app_id = "<YOUR HOCKEY APP ID>"
  hockey_note = RubyBuildIos.latest_git_commit_comment()
  
  # upload_to_hockey(app_id, api_token, note, file_to_upload)
  RubyBuildIos.upload_to_hockey(app_id, api_token, hockey_note, archive_file)
end

def release_to_prod()
  archive_path = './build/prod'
  archive_file = archive_path + '/Example.xcarchive'


  RubyBuildIos.clean('./build')
  
  # Copies the provision file to the appropriately named file in ~/Library/MobileDevice/Provisioning Profiles
  # where Xcode expects to find them.
  RubyBuildIos.install_provision_file('./certs/EXAMPLE_Prod_App.mobileprovision')
  RubyBuildIos.install_provision_file('./certs/EXAMPLE_Prod_WKApp.mobileprovision')
  RubyBuildIos.install_provision_file('./certs/EXAMPLE_Prod_WKExt.mobileprovision')
  
  # build_workspace(workspace, scheme, configuration, build_number, archive_path)
  RubyBuildIos.build_workspace('Example.xcworkspace', 'Example', 'Release', get_build_number_string(), archive_file)

  # This builds the plist necessary to create the ipa from the xcarchive
  # The keys are the bundle ids for the various parts of your app
  # This particular app has a watch app associated
  # The values are the Name baked into the provision file. The one you specified when you created the provision profile
  # You need one entry per profile required for you app. Simple apps need just one. Apps with watch apps need three.
  plist_file = './build/build.plist'
  provision_keys = {
    "com.example.iphoneapp" => "EXAMPLE Prod App",
    "com.example.iphoneapp.watchkitapp" => "EXAMPLE Prod WKApp",
    "com.example.iphoneapp.watchkitapp.extension" => "EXAMPLE Prod WKExt" }
    
  RubyBuildIos.create_export_plist(plist_file, provision_keys)
  
  RubyBuildIos.export_to_ipa(archive_file, plist_file, archive_path)
  
  user = '<YOUR ITUNES UPLOAD USER>'
  password = '<YOUR ITUNES UPLOAD PASS>'
  
  RubyBuildIos.validate_with_itunes(user, password, './build/example.ipa')
end

release_to_qa()
